:py:mod:`byma.iteral.Iteral`
============================

.. py:module:: byma.iteral.Iteral


Module Contents
---------------

Classes
~~~~~~~

.. autoapisummary::

   byma.iteral.Iteral.Iteral




.. py:class:: Iteral


   Defines default options for the Iterative methods sub-package


